pub struct ShipmentConfirmation {Show 17 fields
pub shipment_identifier: String,
pub shipment_confirmation_type: ShipmentConfirmationType,
pub shipment_type: Option<ShipmentType>,
pub shipment_structure: Option<ShipmentStructure>,
pub transportation_details: Option<Box<TransportationDetails>>,
pub amazon_reference_number: Option<String>,
pub shipment_confirmation_date: String,
pub shipped_date: Option<String>,
pub estimated_delivery_date: Option<String>,
pub selling_party: Box<PartyIdentification>,
pub ship_from_party: Box<PartyIdentification>,
pub ship_to_party: Box<PartyIdentification>,
pub shipment_measurements: Option<Box<ShipmentMeasurements>>,
pub import_details: Option<Box<ImportDetails>>,
pub shipped_items: Vec<Item>,
pub cartons: Option<Vec<Carton>>,
pub pallets: Option<Vec<Pallet>>,
}Fields
shipment_identifier: StringUnique shipment ID (not used over the last 365 days).
shipment_confirmation_type: ShipmentConfirmationTypeIndicates if this shipment confirmation is the initial confirmation, or intended to replace an already posted shipment confirmation. If replacing an existing shipment confirmation, be sure to provide the identical shipmentIdentifier and sellingParty information as in the previous confirmation.
shipment_type: Option<ShipmentType>The type of shipment.
shipment_structure: Option<ShipmentStructure>Shipment hierarchical structure.
transportation_details: Option<Box<TransportationDetails>>amazon_reference_number: Option<String>The Amazon Reference Number is a unique identifier generated by Amazon for all Collect/WePay shipments when you submit a routing request. This field is mandatory for Collect/WePay shipments.
shipment_confirmation_date: StringDate on which the shipment confirmation was submitted.
shipped_date: Option<String>The date and time of the departure of the shipment from the vendor’s location. Vendors are requested to send ASNs within 30 minutes of departure from their warehouse/distribution center or at least 6 hours prior to the appointment time at the Amazon destination warehouse, whichever is sooner. Shipped date mentioned in the shipment confirmation should not be in the future.
estimated_delivery_date: Option<String>The date and time on which the shipment is expected to reach buyer’s warehouse. It needs to be an estimate based on the average transit time between ship from location and the destination. The exact appointment time will be provided by the buyer and is potentially not known when creating the shipment confirmation.
selling_party: Box<PartyIdentification>ship_from_party: Box<PartyIdentification>ship_to_party: Box<PartyIdentification>shipment_measurements: Option<Box<ShipmentMeasurements>>import_details: Option<Box<ImportDetails>>shipped_items: Vec<Item>A list of the items in this shipment and their associated details. If any of the item detail fields are common at a carton or a pallet level, provide them at the corresponding carton or pallet level.
cartons: Option<Vec<Carton>>A list of the cartons in this shipment.
pallets: Option<Vec<Pallet>>A list of the pallets in this shipment.
Implementations
sourceimpl ShipmentConfirmation
impl ShipmentConfirmation
pub fn new(
shipment_identifier: String,
shipment_confirmation_type: ShipmentConfirmationType,
shipment_confirmation_date: String,
selling_party: PartyIdentification,
ship_from_party: PartyIdentification,
ship_to_party: PartyIdentification,
shipped_items: Vec<Item>
) -> ShipmentConfirmation